Hbox Example
===============================================================================

:download:`hbox.enaml <../../../examples/layout/basic/hbox.enaml>`

.. literalinclude:: ../../../examples/layout/basic/hbox.enaml
    :language: python

::

 $ enaml-run hbox.enaml

.. image:: images/hbox.png
